@@ -1,12 +1,12 @@
 package Template::Liquid::Filters;
-our $VERSION = '1.0.9';
+our $VERSION = '1.0.10';
 
 sub import {
     Template::Liquid::register_filter(
         qw[ date capitalize upcase downcase first last join split sort size
             strip_html strip_newlines newline_to_br replace replace_first remove
             remove_first truncate truncatewords prepend append minus plus times
-            divided_by modulo round ceil floor abs money stock_price]
+            divided_by modulo round ceil floor abs money stock_price default]
     );
 }
 
@@ -131,10 +131,7 @@ sub modulo {
 }
 sub floor { int $_[0] }
 sub ceil  { int($_[0] + 1) }
-
-sub abs {
-    return CORE::abs($_[0]);
-}
+sub abs   { CORE::abs($_[0]) }
 
 sub money {
     return if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
@@ -154,6 +151,11 @@ sub stock_price {
             CORE::abs($_[0])
     );
 }
+
+sub default {
+    return length $_[0] ? $_[0] : $_[1] if !ref $_[0];
+    return defined $_[0] ? $_[0] : $_[1];
+}
 #
 # TODO
 #sub escape {...}    # Escape's HTML
@@ -509,6 +511,17 @@ Rounds an integer down to the nearest integer.
     {{ 4.6 | floor }} => 4
     {{ 4.3 | floor }} => 4
 
+=head2 C<default>
+
+Sets a default avlue for any variable with no assigned value. Can be used with
+strings, arrays, and hashes.
+
+The default value is returne if the cariable resolves to C<undef> or an empty
+string (C<''>). A string containing whitespace characters will not resolve to
+the default value.
+
+    {{ customer.name | default: "customer" }} => "customer"
+
 =head1 Author
 
 Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
